sge.s — Seclusion Game Engine 1.6 documentation

# sge.s

Contents

- sge.s

This module provides several variables which represent particular important strings. The purpose of these variables (listed below) is to make typos more obvious.

The values of all of these variables are their names as strings. If a variable name starts with an underscore, its value excludes this preceding underscore. For example, a variable called `spam` would have a value of `"spam"`, and a variable called `_1984` would have a value of `"1984"`.

`sge.s.` `_0`

`sge.s.` `_1`

`sge.s.` `_2`

`sge.s.` `_3`

`sge.s.` `_4`

`sge.s.` `_5`

`sge.s.` `_6`

`sge.s.` `_7`

`sge.s.` `_8`

`sge.s.` `_9`

`sge.s.` `a`

`sge.s.` `b`

`sge.s.` `c`

`sge.s.` `d`

`sge.s.` `e`

`sge.s.` `f`

`sge.s.` `g`

`sge.s.` `h`

`sge.s.` `i`

`sge.s.` `j`

`sge.s.` `k`

`sge.s.` `l`

`sge.s.` `m`

`sge.s.` `n`

`sge.s.` `o`

`sge.s.` `p`

`sge.s.` `q`

`sge.s.` `r`

`sge.s.` `s`

`sge.s.` `t`

`sge.s.` `u`

`sge.s.` `v`

`sge.s.` `w`

`sge.s.` `x`

`sge.s.` `y`

`sge.s.` `z`

`sge.s.` `_break`

`sge.s.` `alt_left`

`sge.s.` `alt_right`

`sge.s.` `ampersand`

`sge.s.` `apostrophe`

`sge.s.` `aqua`

`sge.s.` `asterisk`

`sge.s.` `at`

`sge.s.` `axis0`

`sge.s.` `backslash`

`sge.s.` `backspace`

`sge.s.` `backtick`

`sge.s.` `black`

`sge.s.` `blue`

`sge.s.` `bottom`

`sge.s.` `brace_left`

`sge.s.` `brace_right`

`sge.s.` `bracket_left`

`sge.s.` `bracket_right`

`sge.s.` `button`

`sge.s.` `caps_lock`

`sge.s.` `carat`

`sge.s.` `center`

`sge.s.` `colon`

`sge.s.` `comma`

`sge.s.` `ctrl_left`

`sge.s.` `ctrl_right`

`sge.s.` `delete`

`sge.s.` `dissolve`

`sge.s.` `dollar`

`sge.s.` `down`

`sge.s.` `end`

`sge.s.` `enter`

`sge.s.` `equals`

`sge.s.` `escape`

`sge.s.` `euro`

`sge.s.` `exclamation`

`sge.s.` `f0`

`sge.s.` `f1`

`sge.s.` `f2`

`sge.s.` `f3`

`sge.s.` `f4`

`sge.s.` `f5`

`sge.s.` `f6`

`sge.s.` `f7`

`sge.s.` `f8`

`sge.s.` `f9`

`sge.s.` `f10`

`sge.s.` `f11`

`sge.s.` `f12`

`sge.s.` `fade`

`sge.s.` `fuchsia`

`sge.s.` `gray`

`sge.s.` `greater_than`

`sge.s.` `green`

`sge.s.` `hash`

`sge.s.` `hat_center_x`

`sge.s.` `hat_center_y`

`sge.s.` `hat_down`

`sge.s.` `hat_left`

`sge.s.` `hat_right`

`sge.s.` `hat_up`

`sge.s.` `home`

`sge.s.` `hyphen`

`sge.s.` `insert`

`sge.s.` `iris_in`

`sge.s.` `iris_out`

`sge.s.` `isometric`

`sge.s.` `kp_0`

`sge.s.` `kp_1`

`sge.s.` `kp_2`

`sge.s.` `kp_3`

`sge.s.` `kp_4`

`sge.s.` `kp_5`

`sge.s.` `kp_6`

`sge.s.` `kp_7`

`sge.s.` `kp_8`

`sge.s.` `kp_9`

`sge.s.` `kp_divide`

`sge.s.` `kp_enter`

`sge.s.` `kp_equals`

`sge.s.` `kp_minus`

`sge.s.` `kp_multiply`

`sge.s.` `kp_plus`

`sge.s.` `kp_point`

`sge.s.` `left`

`sge.s.` `less_than`

`sge.s.` `lime`

`sge.s.` `maroon`

`sge.s.` `meta_left`

`sge.s.` `meta_right`

`sge.s.` `middle`

`sge.s.` `navy`

`sge.s.` `noblur`

`sge.s.` `num_lock`

`sge.s.` `olive`

`sge.s.` `orthogonal`

`sge.s.` `pagedown`

`sge.s.` `pageup`

`sge.s.` `parenthesis_left`

`sge.s.` `parenthesis_right`

`sge.s.` `pause`

`sge.s.` `percent`

`sge.s.` `period`

`sge.s.` `pixelate`

`sge.s.` `plus`

`sge.s.` `print_screen`

`sge.s.` `purple`

`sge.s.` `question`

`sge.s.` `quote`

`sge.s.` `red`

`sge.s.` `right`

`sge.s.` `scroll_lock`

`sge.s.` `semicolon`

`sge.s.` `shift_left`

`sge.s.` `shift_right`

`sge.s.` `silver`

`sge.s.` `slash`

`sge.s.` `smooth`

`sge.s.` `space`

`sge.s.` `sysrq`

`sge.s.` `tab`

`sge.s.` `teal`

`sge.s.` `top`

`sge.s.` `trackball_down`

`sge.s.` `trackball_left`

`sge.s.` `trackball_right`

`sge.s.` `trackball_up`

`sge.s.` `underscore`

`sge.s.` `up`

`sge.s.` `wheel_down`

`sge.s.` `wheel_left`

`sge.s.` `wheel_right`

`sge.s.` `wheel_up`

`sge.s.` `white`

`sge.s.` `wipe_down`

`sge.s.` `wipe_downleft`

`sge.s.` `wipe_downright`

`sge.s.` `wipe_left`

`sge.s.` `wipe_matrix`

`sge.s.` `wipe_right`

`sge.s.` `wipe_up`

`sge.s.` `wipe_upleft`

`sge.s.` `wipe_upright`

`sge.s.` `yellow`